@@ -31,7 +31,7 @@
 #include <libedataserverui/e-contact-store.h>
 
 #include <e-util/e-util.h>
-#include <e-util/e-alert-dialog.h>
+#include <libevolution-utils/e-alert-dialog.h>
 #include <e-gw-container.h>
 #include <e-gw-connection.h>
 #include <e-gw-message.h>
